==> dialect-sdk-s3-1.2.8-sources.jar: cn/herodotus/oss/dialect/s3/converter/domain/MultipartUploadToDomainConverter.java <==
/*
 * Copyright (c) 2020-2030 码匠君<herodotus@aliyun.com>
 *
 * Dante Cloud licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * <http://www.apache.org/licenses/LICENSE-2.0>
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Dante OSS 采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改 Dante Cloud 源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */

package cn.herodotus.oss.dialect.s3.converter.domain;

import cn.herodotus.oss.definition.attribute.OwnerAttribute;
import cn.herodotus.oss.definition.domain.multipart.MultipartUploadDomain;
import cn.herodotus.oss.dialect.s3.converter.attribute.OwnerToAttributeConverter;
import com.amazonaws.services.s3.model.MultipartUpload;
import com.amazonaws.services.s3.model.Owner;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.core.convert.converter.Converter;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>Description: List<MultipartUpload> 转 List<MultipartUploadDomain> 转换器 </p>
 *
 * @author : gengwei.zheng
 * @date : 2023/8/14 20:35
 */
public class MultipartUploadToDomainConverter implements Converter<List<MultipartUpload>, List<MultipartUploadDomain>> {

    private final Converter<Owner, OwnerAttribute> toAttribute = new OwnerToAttributeConverter();

    @Override
    public List<MultipartUploadDomain> convert(List<MultipartUpload> source) {

        if (CollectionUtils.isNotEmpty(source)) {
            return source.stream().map(this::convert).toList();
        }

        return new ArrayList<>();
    }

    private MultipartUploadDomain convert(MultipartUpload source) {
        MultipartUploadDomain domain = new MultipartUploadDomain();
        domain.setKey(source.getKey());
        domain.setUploadId(source.getUploadId());
        domain.setOwner(toAttribute.convert(source.getOwner()));
        domain.setInitiator(toAttribute.convert(source.getInitiator()));
        domain.setStorageClass(source.getStorageClass());
        domain.setInitiated(source.getInitiated());
        return domain;
    }
}

==> dialect-sdk-s3-3.1.9.0-sources.jar: cn/herodotus/oss/dialect/s3/converter/domain/MultipartUploadToDomainConverter.java <==
/*
 * Copyright (c) 2020-2030 码匠君<herodotus@aliyun.com>
 *
 * Dante Cloud licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * <http://www.apache.org/licenses/LICENSE-2.0>
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Dante OSS 采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改 Dante Cloud 源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 <https://gitee.com/herodotus/dante-oss>
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */

package cn.herodotus.oss.dialect.s3.converter.domain;

import cn.herodotus.oss.specification.domain.base.OwnerDomain;
import cn.herodotus.oss.specification.domain.multipart.UploadDomain;
import com.amazonaws.services.s3.model.MultipartUpload;
import com.amazonaws.services.s3.model.Owner;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.core.convert.converter.Converter;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>Description: List<MultipartUpload> 转 List<UploadDomain> 转换器 </p>
 *
 * @author : gengwei.zheng
 * @date : 2023/8/14 20:35
 */
public class MultipartUploadToDomainConverter implements Converter<List<MultipartUpload>, List<UploadDomain>> {

    private final Converter<Owner, OwnerDomain> toAttribute = new OwnerToDomainConverter();

    @Override
    public List<UploadDomain> convert(List<MultipartUpload> source) {

        if (CollectionUtils.isNotEmpty(source)) {
            return source.stream().map(this::convert).toList();
        }

        return new ArrayList<>();
    }

    private UploadDomain convert(MultipartUpload source) {
        UploadDomain domain = new UploadDomain();
        domain.setKey(source.getKey());
        domain.setUploadId(source.getUploadId());
        domain.setOwner(toAttribute.convert(source.getOwner()));
        domain.setInitiator(toAttribute.convert(source.getInitiator()));
        domain.setStorageClass(source.getStorageClass());
        domain.setInitiated(source.getInitiated());
        return domain;
    }
}
